==> haskell-constraints-0.9-1-i686.pkg.tar.xz: usr/share/haskell/register/haskell-constraints.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: constraints
version: 0.9
id: constraints-0.9-LCN0LfmsvhJCB3djHt91pr
key: constraints-0.9-LCN0LfmsvhJCB3djHt91pr
license: BSD2
copyright: Copyright (C) 2011-2015 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: experimental
homepage: http://github.com/ekmett/constraints/
synopsis: Constraint manipulation
description:
    GHC 7.4 gave us the ability to talk about @ConstraintKinds@. They stopped crashing the compiler in GHC 7.6.
    .
    This package provides a vocabulary for working with them.
category: Constraints
author: Edward A. Kmett
exposed: True
exposed-modules:
    Data.Constraint Data.Constraint.Deferrable Data.Constraint.Forall
    Data.Constraint.Lifting Data.Constraint.Unsafe Data.Constraint.Nat
    Data.Constraint.Symbol
abi: 35a22e5f3d6fae78d87dcc11f453bcca
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/constraints-0.9
library-dirs: /usr/lib/ghc-8.0.1/site-local/constraints-0.9
data-dir: /usr/share/i386-linux-ghc-8.0.1/constraints-0.9
hs-libraries: HSconstraints-0.9-LCN0LfmsvhJCB3djHt91pr
depends:
    base-4.9.0.0 binary-0.8.3.0 deepseq-1.4.2.0 ghc-prim-0.5.0.0
    hashable-1.2.5.0-22n1YftRkmj9O0NzIR6ge1
    mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM transformers-0.5.2.0
    transformers-compat-0.5.1.4-81lZyuOJOvsD0zyCv2TKld
haddock-interfaces: /usr/share/doc/haskell-constraints/html/constraints.haddock
haddock-html: /usr/share/doc/haskell-constraints/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-constraints-0.9.1-2-i686.pkg.tar.xz: usr/share/haskell/register/haskell-constraints.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: constraints
version: 0.9.1
id: constraints-0.9.1-KPDIivdOfwZGRZfHh9qroT
key: constraints-0.9.1-KPDIivdOfwZGRZfHh9qroT
license: BSD2
copyright: Copyright (C) 2011-2015 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: experimental
homepage: http://github.com/ekmett/constraints/
synopsis: Constraint manipulation
description:
    GHC 7.4 gave us the ability to talk about @ConstraintKinds@. They stopped crashing the compiler in GHC 7.6.
    .
    This package provides a vocabulary for working with them.
category: Constraints
author: Edward A. Kmett
exposed: True
exposed-modules:
    Data.Constraint Data.Constraint.Deferrable Data.Constraint.Forall
    Data.Constraint.Lifting Data.Constraint.Unsafe Data.Constraint.Nat
    Data.Constraint.Symbol
abi: fe2f4a24927b43f1db7539a7cc71ea42
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/constraints-0.9.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/constraints-0.9.1
data-dir: /usr/share/i386-linux-ghc-8.0.1/constraints-0.9.1
hs-libraries: HSconstraints-0.9.1-KPDIivdOfwZGRZfHh9qroT
depends:
    base-4.9.0.0 binary-0.8.3.0 deepseq-1.4.2.0 ghc-prim-0.5.0.0
    hashable-1.2.6.0-En2FSYN34Tp8YO8pqagtg1
    mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM transformers-0.5.2.0
    transformers-compat-0.5.1.4-81lZyuOJOvsD0zyCv2TKld
haddock-interfaces: /usr/share/doc/haskell-constraints/html/constraints.haddock
haddock-html: /usr/share/doc/haskell-constraints/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
